import 'dart:io';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:hqsoft_core/core_base/core_base.dart';
import 'package:keyboard_actions/keyboard_actions.dart';
import 'package:keyboard_actions/keyboard_actions_config.dart';
import 'package:keyboard_actions/keyboard_custom.dart';

class KeyboardConfig {
  static KeyboardActionsConfig configOneApplyButton(
      BuildContext context, FocusNode focusNode) {
    return KeyboardActionsConfig(
      keyboardActionsPlatform: KeyboardActionsPlatform.ALL,
      keyboardBarColor: Colors.grey[200],
      nextFocus: true,
      actions: [
        KeyboardActionsItem(focusNode: focusNode, toolbarButtons: [
          (node) {
            return GestureDetector(
              onTap: () => node.unfocus(),
              child: Container(
                // margin: const EdgeInsets.fromLTRB(0, 40, 0, 0),
                padding: EdgeInsets.all(8.0),
                child: Text(allTranslations.text('sys_apply')),
              ),
            );
          }
        ]),
      ],
    );
  }

  // static KeyboardActionsConfig configNumKeyboard(
  //     BuildContext context, FocusNode focusNode, ValueNotifier<String>? notifier) {
  //   return KeyboardActionsConfig(
  //     keyboardActionsPlatform: KeyboardActionsPlatform.ALL,
  //     keyboardBarColor: Colors.grey[200],
  //     nextFocus: true,
  //     actions: [
  //       KeyboardActionsItem(
  //         focusNode: focusNode,
  //         displayActionBar: false,
  //         footerBuilder: (_) => HexKeyboard(
  //           focusNode: focusNode,
  //           notifier: notifier,
  //         ),
  //       ),
  //     ],
  //   );
  // }
}

// class HexKeyboard extends StatelessWidget
//     with KeyboardCustomPanelMixin<String>
//     implements PreferredSizeWidget {
//   //final ValueNotifier<String>? notifier;
//   final ValueNotifier<dynamic>? notifier;
//   final FocusNode? focusNode;
//
//   HexKeyboard({
//     this.notifier,
//     this.focusNode,
//   });
//
//   @override
//   Size get preferredSize => Size.fromHeight(280);
//
//   final format = NumberFormat(); //NumberFormat("0000");
//
//   String _formatValue(String value) {
//     final updatedValue = value; //format.format(double.parse(value));
//     /*final finalValue = updatedValue.substring(0, updatedValue.length - 2) +
//         "." +
//         updatedValue.substring(updatedValue.length - 2, updatedValue.length);*/
//     final finalValue = updatedValue;
//     return finalValue;
//   }
//
//   void _onTapNumber(String value) {
//     if (value == "Done") {
//       focusNode!.unfocus();
//       return;
//     }
//     final currentValue = notifier!.value.replaceAll(".", "");
//     final temp = currentValue + value;
//     updateValue(_formatValue(temp));
//   }
//
//   void _onTapBackspace() {
//     final currentValue = notifier!.value.replaceAll(".", "");
//     final temp = currentValue.substring(0, currentValue.length - 1);
//     updateValue(_formatValue(temp));
//   }
//
//   @override
//   Widget build(BuildContext context) {
//     return Container(
//       height: preferredSize.height,
//       color: Color(0xFF313131),
//       child: Padding(
//         padding: const EdgeInsets.all(8.0),
//         child: GridView(
//           shrinkWrap: true,
//           gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
//             crossAxisCount: 3,
//             childAspectRatio: 2.2,
//             crossAxisSpacing: 10,
//             mainAxisSpacing: 10,
//           ),
//           children: [
//             _buildButton(text: "7"),
//             _buildButton(text: "8"),
//             _buildButton(text: "9"),
//             _buildButton(text: "4"),
//             _buildButton(text: "5"),
//             _buildButton(text: "6"),
//             _buildButton(text: "1"),
//             _buildButton(text: "2"),
//             _buildButton(text: "3"),
//             _buildButton(text: "0"),
//             _buildButton(text: "A"),
//             _buildButton(text: "B"),
//             _buildButton(text: "C"),
//             _buildButton(text: "D"),
//             _buildButton(text: "E"),
//             _buildButton(text: "F"),
//             _buildButton(icon: Icons.backspace, color: Colors.black),
//             _buildButton(text: "Done", color: Colors.black),
//           ],
//         ),
//       ),
//     );
//   }
//
//   Widget _buildButton({
//     String? text,
//     IconData? icon,
//     Color? color,
//   }) =>
//       NumericButton(
//         text: text.toString(),
//         icon: icon as IconData,
//         color: color as Color,
//         onTap: () => icon != null ? _onTapBackspace() : _onTapNumber(text!),
//       );
// }

class NumericButton extends StatelessWidget {
  final String? text;
  final VoidCallback? onTap;
  final IconData? icon;
  final Color? color;

  const NumericButton({
    this.text,
    this.onTap,
    this.icon,
    this.color,
  })  ;

  @override
  Widget build(BuildContext context) {
    return Material(
      borderRadius: BorderRadius.circular(5.0),
      color: color ?? Color(0xFF4A4A4A),
      elevation: 5,
      child: InkWell(
        onTap: onTap,
        child: FittedBox(
          child: Padding(
            padding: const EdgeInsets.all(3.0),
            child: icon != null
                ? Icon(
                    icon,
                    color: Colors.white,
                  )
                : Text(
                    text!,
                    style: TextStyle(
                      color: Colors.white,
                      fontWeight: FontWeight.w300,
                    ),
                  ),
          ),
        ),
      ),
    );
  }
}

class InputDoneView extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Container(
      width: double.infinity,
      height: 40,
      color: Colors.grey,
      child: Align(
        alignment: Alignment.topRight,
        child: Padding(
          padding: const EdgeInsets.only(top: 4.0, bottom: 4.0),
          child: CupertinoButton(
            padding: EdgeInsets.only(right: 24.0, top: 8.0, bottom: 8.0),
            onPressed: () {
              FocusScope.of(context).requestFocus(new FocusNode());
            },
            child: Text("Done",
                style: TextStyle(
                    color: Colors.white, fontWeight: FontWeight.bold)),
          ),
        ),
      ),
    );
  }
}

//https://blog.usejournal.com/keyboard-done-button-ux-in-flutter-ios-app-3b29ad46bacc
class KeyboardOverlay {
  static OverlayEntry? _overlayEntry;

  static showOverlay(BuildContext context) {
    if (_overlayEntry != null) {
      return;
    }
    if (Platform.isAndroid) {
      return;
    }
    OverlayState? overlayState = Overlay.of(context);
    _overlayEntry = OverlayEntry(builder: (context) {
      return Positioned(
          bottom: MediaQuery.of(context).viewInsets.bottom ,
          right: 0.0,
          left: 0.0,
          child: InputDoneView());
    });

    overlayState!.insert(_overlayEntry!);
  }

  static removeOverlay() {
    if (_overlayEntry != null) {
      _overlayEntry!.remove();
      _overlayEntry = null;
    }
  }
}
